summaryrefslogtreecommitdiffstats
path: root/pyuic2/uic.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'pyuic2/uic.cpp')
-rw-r--r--pyuic2/uic.cpp14
1 files changed, 7 insertions, 7 deletions
diff --git a/pyuic2/uic.cpp b/pyuic2/uic.cpp
index fc470f3..2f445e5 100644
--- a/pyuic2/uic.cpp
+++ b/pyuic2/uic.cpp
@@ -260,11 +260,11 @@ void Uic::createFormImpl( const TQDomElement &e )
}
}
- // find out what images are retquired
- TQStringList retquiredImages;
+ // find out what images are required
+ TQStringList requiredImages;
nl = e.elementsByTagName( "pixmap" );
for ( int j = 0; j < (int) nl.length(); j++ ) {
- retquiredImages += nl.item(j).firstChild().toText().data();
+ requiredImages += nl.item(j).firstChild().toText().data();
}
TQStringList images;
@@ -277,7 +277,7 @@ void Uic::createFormImpl( const TQDomElement &e )
for ( i = 0; i < (int) nl.length(); i++ ) {
TQDomElement tmp = nl.item(i).firstChild().toElement();
TQString img = registerObject( tmp.firstChild().toText().data() );
- if ( !retquiredImages.contains( img ) )
+ if ( !requiredImages.contains( img ) )
continue;
tmp = tmp.nextSibling().toElement();
TQString format = tmp.attribute("format", "PNG" );
@@ -424,7 +424,7 @@ void Uic::createFormImpl( const TQDomElement &e )
}
- // create all children, some forms have special retquirements
+ // create all children, some forms have special requirements
if ( objClass == "TQWizard" ) {
for ( n = e.firstChild().toElement(); !n.isNull(); n = n.nextSibling().toElement() ) {
@@ -540,7 +540,7 @@ void Uic::createFormImpl( const TQDomElement &e )
// end of constructor
popIndent();
// handle application font changes if retquired
nl = e.elementsByTagName( "widget" );
bool needEventHandler = FALSE;
for ( i = 0; i < (int) nl.length(); i++ ) {
@@ -734,7 +734,7 @@ TQString Uic::createObjectImpl( const TQDomElement &e, const TQString& parentCla
}
}
- // create all children, some widgets have special retquirements
+ // create all children, some widgets have special requirements
if ( objClass == "TQTabWidget" ) {
for ( n = e.firstChild().toElement(); !n.isNull(); n = n.nextSibling().toElement() ) {
@@ -540,7 +540,7 @@ void Uic::createFormImpl( const TQDomElement &e )
// end of constructor
popIndent();
- // handle application font changes if retquired
+ // handle application font changes if required
nl = e.elementsByTagName( "widget" );
bool needEventHandler = FALSE;